@@ -1,5 +1,5 @@
 package Mira::Plugin::Date::Jalali;
-$Mira::Plugin::Date::Jalali::VERSION = '00.07.35';
+$Mira::Plugin::Date::Jalali::VERSION = '00.07.36';
 
 use strict;
 use warnings;
@@ -228,9 +228,7 @@ separate methods
 
 =head1 AUTHOR
 
-Kiavash
-
-Ahmad Anvari <http://www.anvari.org/bio/>
+kiamazi C<kiavash@cpan.org>
 
 Redistributed by : Ehsan Golpayegani <http://www.golpayegani.com>
 
